@@ -33,7 +33,7 @@
  */
 
 #ifndef lint
-static char sccsid[] = "@(#)headers.c	8.111 (Berkeley) 7/9/97";
+static char sccsid[] = "@(#)headers.c	8.115 (Berkeley) 10/22/97";
 #endif /* not lint */
 
 # include <errno.h>
@@ -522,9 +522,16 @@ eatheader(e, full)
 			(void) sendtolist(h->h_value, NULLADDR,
 					  &e->e_sendqueue, 0, e);
 
+#if 0
+			/*
+			** Change functionality so a fatal error on an
+			** address doesn't affect the entire envelope.
+			*/
+			 
 			/* delete fatal errors generated by this address */
-			if (!GrabTo && !bitset(EF_FATALERRS, saveflags))
+			if (!bitset(EF_FATALERRS, saveflags))
 				e->e_flags &= ~EF_FATALERRS;
+#endif
 		}
 
 		/* save the message-id for logging */
@@ -1330,7 +1337,7 @@ put_vanilla_header(h, v, mci)
 	int putflags;
 	char obuf[MAXLINE];
 
-	putflags = 0;
+	putflags = PXLF_HEADER;
 #if _FFR_7BITHDRS
 	if (bitnset(M_7BITHDRS, mci->mci_mailer->m_flags))
 		putflags |= PXLF_STRIP8BIT;
@@ -1342,8 +1349,8 @@ put_vanilla_header(h, v, mci)
 		int l;
 
 		l = nlp - v;
-		if (sizeof obuf - (obp - obuf) < l)
-			l = sizeof obuf - (obp - obuf);
+		if (SPACELEFT(obuf, obp) - 1 < l)
+			l = SPACELEFT(obuf, obp) - 1;
 
 		snprintf(obp, SPACELEFT(obuf, obp), "%.*s", l, v);
 		putxline(obuf, strlen(obuf), mci, putflags);
@@ -1385,7 +1392,7 @@ commaize(h, p, oldstyle, mci, e)
 	int opos;
 	int omax;
 	bool firstone = TRUE;
-	int putflags = 0;
+	int putflags = PXLF_HEADER;
 	char obuf[MAXLINE + 3];
 
 	/*
@@ -1491,6 +1498,7 @@ commaize(h, p, oldstyle, mci, e)
 			*p = savechar;
 			continue;
 		}
+		name = denlstring(name, FALSE, TRUE);
 
 		/* output the name with nice formatting */
 		opos += strlen(name);
