@@ -33,7 +33,7 @@
  */
 
 #ifndef lint
-static char sccsid[] = "@(#)parseaddr.c	8.128 (Berkeley) 6/14/97";
+static char sccsid[] = "@(#)parseaddr.c	8.132 (Berkeley) 10/20/97";
 #endif /* not lint */
 
 # include "sendmail.h"
@@ -1859,6 +1859,7 @@ struct qflags	AddressFlags[] =
 	{ "QDELIVERED",		QDELIVERED	},
 	{ "QDELAYED",		QDELAYED	},
 	{ "QTHISPASS",		QTHISPASS	},
+	{ "QRCPTOK",		QRCPTOK		},
 	{ NULL }
 };
 
@@ -2136,7 +2137,11 @@ maplocaluser(a, sendq, aliaslevel, e)
 	}
 	pvp = prescan(a->q_user, '\0', pvpbuf, sizeof pvpbuf, &delimptr, NULL);
 	if (pvp == NULL)
+	{
+		if (tTd(29, 9))
+			printf("maplocaluser: cannot prescan %s\n", a->q_user);
 		return;
+	}
 
 	define('h', a->q_host, e);
 	define('u', a->q_user, e);
@@ -2144,17 +2149,25 @@ maplocaluser(a, sendq, aliaslevel, e)
  
 	if (rewrite(pvp, 5, 0, e) == EX_TEMPFAIL)
 	{
+		if (tTd(29, 9))
+			printf("maplocaluser: rewrite tempfail\n");
 		a->q_flags |= QQUEUEUP;
 		a->q_status = "4.4.3";
 		return;
 	}
 	if (pvp[0] == NULL || (pvp[0][0] & 0377) != CANONNET)
+	{
+		if (tTd(29, 9))
+			printf("maplocaluser: doesn't resolve\n");
 		return;
+	}
 
 	/* if non-null, mailer destination specified -- has it changed? */
 	a1 = buildaddr(pvp, NULL, 0, e);
 	if (a1 == NULL || sameaddr(a, a1))
 	{
+		if (tTd(29, 9))
+			printf("maplocaluser: address unchanged\n");
 		if (a1 != NULL)
 			free(a1);
 		return;
@@ -2349,7 +2362,6 @@ rscheck(rwset, p1, p2, e)
 	auto ADDRESS a1;
 	bool saveQuickAbort = QuickAbort;
 	bool saveSuprErrs = SuprErrs;
-	bool saveOnlyOneError = OnlyOneError;
 	char buf0[MAXLINE];
 	char pvpbuf[PSBUFSIZE];
 	extern char MsgBuf[];
@@ -2387,7 +2399,7 @@ rscheck(rwset, p1, p2, e)
 		(void) snprintf(buf, bufsize, "%s", p1);
 	}
 	SuprErrs = TRUE;
-	OnlyOneError = QuickAbort = FALSE;
+	QuickAbort = FALSE;
 	pvp = prescan(buf, '\0', pvpbuf, sizeof pvpbuf, NULL, NULL);
 	SuprErrs = saveSuprErrs;
 	if (pvp == NULL)
@@ -2413,25 +2425,38 @@ rscheck(rwset, p1, p2, e)
 
 	if (LogLevel >= 4)
 	{
-		if (p2 == NULL)
-			sm_syslog(LOG_NOTICE, e->e_id,
-				"Ruleset %s (%s) rejection: %s",
-				rwset, p1, MsgBuf);
-		else
-			sm_syslog(LOG_NOTICE, e->e_id,
-				"Ruleset %s (%s, %s) rejection: %s",
-				rwset, p1, p2, MsgBuf);
+		char *relay;
+		char *p;
+		char lbuf[MAXLINE];
+
+		p = lbuf;
+		if (p2 != NULL)
+		{
+			snprintf(p, SPACELEFT(lbuf, p),
+				", arg2=%s",
+				p2);
+			p += strlen(p);
+		}
+		if ((relay = macvalue('_', e)) != NULL)
+		{
+			snprintf(p, SPACELEFT(lbuf, p),
+				", relay=%s", relay);
+			p += strlen(p);
+		}
+		*p = '\0';
+		sm_syslog(LOG_NOTICE, e->e_id,
+			"ruleset=%s, arg1=%s%s, reject=%s",
+			rwset, p1, lbuf, MsgBuf);
 	}
 
  finis:
 	/* clean up */
 	QuickAbort = saveQuickAbort;
-	OnlyOneError = saveOnlyOneError;
 	setstat(rstat);
 	if (buf != buf0)
 		free(buf);
 
-	if (rstat != EX_OK && (QuickAbort || (OnlyOneError && !HoldErrs)))
+	if (rstat != EX_OK && QuickAbort)
 		longjmp(TopFrame, 2);
 	return rstat;
 }
